@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -21,6 +21,16 @@ include("library.js");
 include("AddOn.js");
 include("scripts/File/OpenFile/OpenFile.js");
 include("scripts/File/AutoSave/AutoSave.js");
+include("scripts/Tools/arguments.js");
+
+// allow plugins to extend autostart through autostart1.js, autostart2.js, ...:
+for (var i=1; i<10; i++) {
+    var fn = "scripts/autostart" + i + ".js";
+    if (new QFileInfo(fn).exists() || new QFileInfo(":/" + fn).exists()) {
+        include(fn);
+    }
+}
+
 
 /**
  * Prints version information.
@@ -37,7 +47,7 @@ function version() {
  * Prints command line usage information on stdout.
  */
 function usage() {
-    print("\nUsage: " + QCoreApplication.arguments()[0] + " [Options] [Files to open]\n"
+    print("\nUsage: " + RSettings.getOriginalArguments()[0] + " [Options] [Files to open]\n"
           + "\n"
           + "-allow-multiple-instances        Don't try to avoid multiple instances from running\n"
           + "                                 simultaneously.\n"
@@ -54,14 +64,16 @@ function usage() {
           + "                                 implemented in the given script.\n"
           + "-config [path]                   Reads and stores settings in a configuration file\n"
           + "                                 at the given location instead of the default location.\n"
+          + "-debug-action-order              Print action order information in menus\n"
           + "-enable-script-debugger          Enables the script debugger.\n"
           + "                                 NOT recommended as this may cause unexpected\n"
           + "                                 behavior when using QCAD.\n"
-          + "-debug-action-order              Print action oder information in menus\n"
           + "-exec [script file] [options]    Executes the given script file directly\n"
           + "                                 after staring QCAD. Options after the script\n"
           + "                                 file are passed on to the script.\n"
           + "-help                            Displays this help.\n"
+          + "-ignore-script-files             Ignore script files on disk.\n"
+          + "                                 Only load scripts from plugins if applicable.\n"
           + "-locale [locale]                 Sets the locale to be used (overrides\n"
           + "                                 the language set in the preferences).\n"
           + "                                 E.g. '-locale de' starts QCAD in German.\n"
@@ -77,135 +89,11 @@ function usage() {
           + "                                 given script(s).\n"
     );
 
-    // Mac OS X only:
-    if (RS.getSystemId()==="osx") {
-        print("\nMac OS X specific options:\n");
-        print("-no-dock-icon                    Don't show icon in dock. This should only be used\n"
-            + "                                 in combination with -no-gui."  );
-    }
+    printGenericUsage();
 
     print("\n");
 }
 
-/**
- * Open files given as arguments args or creates a new document if
- * no files are given and createNew is true.
- */
-function openFiles(args, createNew) {
-    var appWin = RMainWindowQt.getMainWindow();
-    if (isNull(appWin)) {
-        // application is shutting down..
-        return;
-    }
-    var mdiArea = appWin.getMdiArea();
-    var mdiChildren = mdiArea.subWindowList();
-    var foundFile = false;
-    var filter = undefined;
-
-    for (var i = 0; i < args.length; ++i) {
-        // arguments with one parameter:
-        if (args[i] === "-locale" || args[i] === "-autostart"
-            || args[i] === "-app-id" || args[i] === "-ignore"
-            || args[i] === "-config") {
-            // skip 2 arguments
-            i++;
-            if (i>=args.length) {
-                break;
-            }
-            continue;
-        }
-
-        // argument with two parameters
-        if (args[i] === "-font-substitution" || args[i] === "-fs") {
-            // skip 3 arguments
-            i+=2;
-            if (i>=args.length) {
-                break;
-            }
-            continue;
-        }
-
-        if (isNull(args[i])) {
-            continue;
-        }
-
-        // all arguments after -exec are script files or script arguments:
-        if (args[i] === "-exec") {
-            break;
-        }
-
-        if (args[i] === "-filter") {
-            if (++i>=args.length) {
-                break;
-            }
-            filter = args[i];
-            continue;
-        }
-
-
-        // skip other arguments without parameter:
-        if (args[i][0] === "-") {
-            continue;
-        }
-
-        foundFile = true;
-        var foundExisting = false;
-
-        var arg = args[i];
-        var isLocalFile = true;
-
-        if (isUrl(arg)) {
-            var url = new QUrl(arg);
-            if (url.isLocalFile()) {
-                // arg is now a path:
-                arg = url.toLocalFile();
-            }
-            else {
-                isLocalFile = false;
-            }
-        }
-
-        if (isLocalFile) {
-            // if the file is already open, activate that appropriate sub window instead
-            // of opening the file again:
-            var document = undefined;
-            var fileName = undefined;
-            var fileInfo = undefined;
-            var argFileInfo = undefined;
-            for (var k=0; k<mdiChildren.length; k++) {
-                document = mdiChildren[k].getDocument();
-                fileName = document.getFileName();
-                fileInfo = new QFileInfo(fileName);
-                argFileInfo = new QFileInfo(getAbsolutePathForArg(arg));
-
-                if (fileInfo.absoluteFilePath()===argFileInfo.absoluteFilePath()) {
-                    mdiArea.setActiveSubWindow(mdiChildren[k]);
-                    foundExisting = true;
-                    break;
-                }
-            }
-        }
-
-        // open the file if it is not already open:
-        if (!foundExisting) {
-            if (isLocalFile) {
-                NewFile.createMdiChild(getAbsolutePathForArg(arg), filter);
-            }
-            else {
-                NewFile.createMdiChild(arg, filter);
-            }
-        }
-    }
-
-    // create new document if no files were loaded:
-    if (!foundFile && createNew===true) {
-        var fileNewAction = RGuiAction.getByScriptFile("scripts/File/NewFile/NewFile.js");
-        if (!isNull(fileNewAction)) {
-            fileNewAction.slotTrigger();
-        }
-    }
-}
-
 /**
  * Executes the scripts that are given as arguments of -exec.
  * \return true if the application should quit after executing the
@@ -218,24 +106,36 @@ function execScripts(args) {
             if (isNull(args[i])) {
                 break;
             }
-            // run existing action:
+
+            // check for existing action (e.g. "scripts/File/NewFile/NewFile.js"):
             var action = RGuiAction.getByScriptFile(args[i]);
+
+            // script is not an existing action:
             if (isNull(action)) {
-                // gui action might not exist yet for this script, create one:
-                var resPath = args[i];
-                action = new RGuiAction("");
-                if (!new QFileInfo(resPath).exists()) {
-                    resPath = ":/" + resPath;
-                }
-                if (!new QFileInfo(resPath).exists()) {
-                    action = undefined;
+                // include (run) script which might or might not be action:
+                var scriptFile = args[i];
+                var scriptFilePath = getAbsolutePathForArg(scriptFile);
+                if (new QFileInfo(scriptFilePath).exists()) {
+
+                    // including the script evaluates (runs) it:
+                    include(scriptFilePath);
+
+                    // check if script created a class of same name as file base name:
+                    var fi = new QFileInfo(scriptFile);
+                    var className = fi.baseName();
+                    if (!isNull(global[className])) {
+                        // gui action might not exist yet for this script, create one:
+                        action = new RGuiAction("");
+                        action.setScriptFile(scriptFilePath);
+                        action.setRequiresDocument(false);
+                    }
                 }
                 else {
-                    action.setScriptFile(resPath);
-                    action.setRequiresDocument(false);
+                    qWarning("script not found: ", args[i]);
                 }
             }
 
+            // script is action or created action:
             if (!isNull(action)) {
                 ++i;
                 // handle script arguments:
@@ -246,18 +146,6 @@ function execScripts(args) {
                 --i;
                 action.slotTrigger();
             }
-
-            else {
-                // include (run) script which is not an action:
-                var scriptFile = args[i];
-                var path = getAbsolutePathForArg(scriptFile);
-                if (new QFileInfo(path).exists()) {
-                    include(path);
-                }
-                else {
-                    qWarning("script not found: ", args[i]);
-                }
-            }
         }
         if (args[i] === "-quit") {
             RSettings.setQuitFlag();
@@ -266,7 +154,7 @@ function execScripts(args) {
 }
 
 /**
- * Sets up drag and drop support (droping files on the application window
+ * Sets up drag and drop support (dropping files on the application window
  * opens them).
  */
 function setUpDragAndDrop(appWin) {
@@ -274,7 +162,8 @@ function setUpDragAndDrop(appWin) {
         event.acceptProposedAction();
     });
 
-    appWin.drop.connect(function(evt) {
+    appWin.drop.connect(function(event) {
+        // workaround for Qt keyboard focus bug:
         var appWin = RMainWindowQt.getMainWindow();
         if (!isNull(appWin)) {
             appWin.activateWindow();
@@ -282,13 +171,15 @@ function setUpDragAndDrop(appWin) {
             appWin.setFocus(Qt.OtherFocusReason);
         }
 
-        var urls = getUrlsFromMimeData(evt.mimeData());
+        var urls = getUrlsFromMimeData(event.mimeData());
         var urlStrings = [];
         for (var i = 0; i < urls.length; ++i) {
             urlStrings.push(urls[i].toString());
         }
 
         openFiles(urlStrings, false);
+
+        event.acceptProposedAction();
     });
 }
 
@@ -297,9 +188,6 @@ function setUpDragAndDrop(appWin) {
  */
 function loadTranslations(addOns, splash) {
     var locale = RSettings.getLocale();
-    if (locale === "en" || locale.toLowerCase() === "en_us") {
-        return;
-    }
 
     if (!isNull(splash)) {
         // no translations yet:
@@ -308,22 +196,51 @@ function loadTranslations(addOns, splash) {
 
     // load C++ translations:
     var modules = ["qt", "assistant", "qt_help", "qcadcore", "qcadentity", "qcadgui"];
+    if (RSettings.isQt(5) || RSettings.isQt(6)) {
+        modules.unshift("qtbase");
+    }
+
+    var i;
+    var module;
+
     for (var mi=0; mi<modules.length; ++mi) {
-        var module = modules[mi];
+        module = modules[mi];
 
         RSettings.loadTranslations(module);
     }
 
+    //RSettings.loadTranslations("scripts_" + locale, [autoPath("scripts/ts")]);
 
-    // install one QTranslator for each script add-on:
+    // load translations from arguments:
+    var args = RSettings.getOriginalArguments();
+    for (i = 0; i < args.length; ++i) {
+        if (args[i] === "-ts") {
+            if (++i>=args.length) {
+                break;
+            }
+            module = args[i];
+            if (++i>=args.length) {
+                break;
+            }
+            var dir = args[i];
+
+            RSettings.loadTranslations(module, [autoPath(dir)]);
+        }
+    }
+
+//    RSettings.loadTranslations("scripts", [autoPath("ts")]);
+//    RSettings.loadTranslations("proscripts", [autoPath("../qcadpro/ts")]);
+//    RSettings.loadTranslations("camscripts", [autoPath("../qcadcam/ts")]);
+
+    // install one QTranslator for each script add-on if available:
     if (!isNull(splash)) {
         splash.showMessage(qsTr("Loading add-on translations...") + "\n", Qt.AlignBottom);
         QCoreApplication.processEvents();
     }
 
-    RSettings.loadTranslations("Scripts_" + locale, ["scripts/ts"]);
+    //RSettings.loadTranslations("Scripts_" + locale, [autoPath("scripts/ts")]);
 
-    for (var i = 0; i < addOns.length; ++i) {
+    for (i = 0; i < addOns.length; ++i) {
         var addOn = addOns[i];
         if (isNull(addOn)) {
             qWarning("Null add on found");
@@ -386,10 +303,10 @@ function initAddOns(addOns, splash) {
 }
 
 function postInitAddOns(addOns, splash) {
-    if (!isNull(splash)) {
-        splash.showMessage(qsTr("Post-initializing add-ons...") + "\n", Qt.AlignBottom);
-        QCoreApplication.processEvents();
-    }
+//    if (!isNull(splash)) {
+//        splash.showMessage(qsTr("Post-initializing add-ons...") + "\n", Qt.AlignBottom);
+//        QCoreApplication.processEvents();
+//    }
 
     var addOn;
     var i;
@@ -427,7 +344,7 @@ function main() {
     var i;
     var filesToOpen = [];
 
-    // open file that was clicked in Finder if application was not yet running (Mac OS X):
+    // open file that was clicked in Finder if application was not yet running (macOS):
     qApp.fileOpenRequestReceived.connect(function(fileName) {
         filesToOpen.push(fileName);
     });
@@ -440,7 +357,7 @@ function main() {
         execScripts(args);
     });
 
-    var args = QCoreApplication.arguments();
+    var args = RSettings.getOriginalArguments();
     if (args.contains("-help") || args.contains("-h")) {
         usage();
         return;
@@ -462,16 +379,6 @@ function main() {
     // make sure settings file path is reinitialized:
     RSettings.uninit();
 
-    // alternative path for QCAD3.ini:
-    for (i=1; i<args.length; ++i) {
-        if (args[i] === "-config") {
-            ++i;
-            if (i < args.length) {
-                QSettings.setPath(QSettings.IniFormat, QSettings.UserScope, getAbsolutePathForArg(args[i]));
-            }
-        }
-    }
-
     // ignore config file if it does not identify itself with a version
     // number or is known as being incompatible
     var reset = false;
@@ -521,28 +428,36 @@ function main() {
     }
 
     // detect very first start of this installation:
-    var fiSettings = new QFileInfo(RSettings.getQSettings().fileName());
+    var fiSettings = new QFileInfo(RSettings.getFileName());
     var isFirstStart = !fiSettings.exists();
 
     var numPlugins = RPluginLoader.countPlugins();
     var pluginInfo;
 
     // look up app name override:
+    var maxPri = 0;
     for (i=0; i<numPlugins; i++) {
         pluginInfo = RPluginLoader.getPluginInfo(i);
-        var n = pluginInfo.get("NameOverride");
-        if (!isNull(n)) {
-            qApp.applicationName = n;
+        var np = pluginInfo.get("OverridePriority", "0");
+        np = parseInt(np);
+        if (parseInt(np)>maxPri) {
+            maxPri = np;
+            var n = pluginInfo.get("NameOverride", "");
+            if (n.length>0) {
+                qApp.applicationName = n;
+            }
         }
     }
 
     // if locale is given, don't show first start dialog:
-    if (isFirstStart && !QCoreApplication.arguments().contains("-locale")) {
-        include("Widgets/FirstStart/FirstStart.js");
+    if (isFirstStart && !args.contains("-locale")) {
+        include("scripts/Widgets/FirstStart/FirstStart.js");
         var first = new FirstStart();
         first.showDialog();
     }
 
+    RPluginLoader.initTranslations();
+
     // correct library paths from 'library' to 'libraries':
     if (RSettings.getIntValue("Application/Version", 0)<=3000008) {
         var oldDefaultSource = new QFileInfo("library").absoluteFilePath();
@@ -560,9 +475,14 @@ function main() {
     // theme:
     applyTheme();
 
+    // native / non-native menubar:
+    if (RSettings.getBoolValue("MenuBar/UseNativeMenuBar", true)===false) {
+        QCoreApplication.setAttribute(Qt.AA_DontUseNativeMenuBar);
+    }
+
     // splash:
     var splash = undefined;
-    if (RSettings.getBoolValue("Start/EnableSplashScreen", true)) {
+    if (RSettings.getBoolValue("Startup/EnableSplashScreen", true) && !args.contains("-no-show")) {
         var fn;
         var key;
         if (RSettings.getDevicePixelRatio()===2) {
@@ -575,37 +495,56 @@ function main() {
         }
 
         // look up slash screen override:
+        var maxPri = undefined;
         for (i=0; i<numPlugins; i++) {
             pluginInfo = RPluginLoader.getPluginInfo(i);
-            var s = pluginInfo.get(key);
-            if (!isNull(s)) {
-                fn = s;
-                qDebug("splash override: ", fn);
+
+            // override priority:
+            var pri = pluginInfo.get("OverridePriority");
+            if (!isNull(pri)) {
+                pri = parseInt(pri);
+            }
+            else {
+                // default to lowest priority:
+                pri = 0;
+            }
+
+            if (isNull(maxPri) || pri>maxPri) {
+                var s = pluginInfo.get(key);
+                if (!isNull(s)) {
+                    fn = s;
+                    maxPri = pri;
+                }
             }
         }
 
         var pixmap = new QPixmap(fn);
         splash = new QSplashScreen(pixmap);
-        if (!QCoreApplication.arguments().contains("-no-show")) {
-            splash.show();
-        }
+        splash.objectName = "Splash";
+        splash.show();
     }
 
     RFontList.initSubstitutions();
 
-    RPluginLoader.postInitPlugins(RPluginInterface.GotSplashWindow);
-
     // mark config file with current version number:
     var previousVersion = RSettings.getStringValue("Application/Version", "");
     RSettings.setValue("Application/Version", RSettings.getNumericalVersionString());
 
+    // save first start information:
+    RSettings.setFirstStart(isFirstStart);
+    // save new version information:
+    RSettings.setNewVersion(newVersion);
+    RSettings.setPreviousVersion(parseInt(previousVersion, 10));
+
+    RPluginLoader.postInitPlugins(RPluginInterface.GotSplashWindow);
+
     // scan for script add-ons (forced for first start, first start after
     // update, if configured):
     var addOns;
     var addOnFilePaths = RSettings.getValue("AddOns/List", []);
     if (addOnFilePaths.length===0 || newVersion ||
-            QCoreApplication.arguments().contains("-rescan") ||
-            RSettings.getBoolValue("Scripting/Rescan", true)===true) {
+        args.contains("-rescan") ||
+        RSettings.getBoolValue("Scripting/Rescan", true)===true) {
 
         if (!isNull(splash)) {
             // no translations yet:
@@ -632,20 +571,17 @@ function main() {
 
     // create application window:
     var appWin = new RMainWindowQt();
-    if (RSettings.getQtVersionString().startsWith("4.")) {
-        // animated is nice, but crashes sometimes (Qt 4.7.2):
-        // Qt 5.7.0 will not allow tabifying dock widgets if animations are turned off:
+
+    // Note: animated MUST be true for Qt 5.7:
+    // Qt 5.7.0 will not allow tabifying dock widgets if animations are turned off:
+    if (RSettings.getQtVersion()<0x050600) {
+        // animated must be false for Qt 4.7.2, 5.6.0 (crashes):
         appWin.animated = false;
     }
+
     appWin.objectName = "MainWindow";
     appWin.windowTitle = qApp.applicationName;
 
-    // save first start information:
-    RSettings.setFirstStart(isFirstStart);
-    // save new version information:
-    RSettings.setNewVersion(newVersion);
-    RSettings.setPreviousVersion(parseInt(previousVersion, 10));
-
     // save locale
     appWin.setProperty("Locale", RSettings.getLocale());
     
@@ -654,16 +590,23 @@ function main() {
     menuBar.objectName = "MenuBar";
 
     // load add-ons:
-    RDebug.startTimer(0);
+    //RDebug.startTimer(0);
     loadAddOns(addOns, splash);
-    RDebug.stopTimer(0, "loading add-ons");
+    //RDebug.stopTimer(0, "loading add-ons");
 
-    RDebug.startTimer(0);
+    //RDebug.startTimer(0);
     initAddOns(addOns, splash);
-    RDebug.stopTimer(0, "initializing add-ons");
+    //RDebug.stopTimer(0, "initializing add-ons");
 
     // auto load scripts in AutoLoad folders for global script engine:
-    var files = RAutoLoadEcma.getAutoLoadFiles();
+
+    var files;
+    if (RSettings.isQt(6)) {
+        files = RAutoLoadJs.getAutoLoadFiles();
+    }
+    else {
+        files = RAutoLoadEcma.getAutoLoadFiles();
+    }
     for (i=0; i<files.length; i++) {
         include(files[i]);
     }
@@ -682,31 +625,31 @@ function main() {
     appWin.setCorner(Qt.TopRightCorner, Qt.RightDockWidgetArea);
     appWin.setCorner(Qt.BottomRightCorner, Qt.RightDockWidgetArea);
     appWin.setTabPosition(Qt.RightDockWidgetArea, QTabWidget.West);
-    appWin.setTabPosition(Qt.LeftDockWidgetArea, QTabWidget.South);
+    appWin.setTabPosition(Qt.LeftDockWidgetArea, QTabWidget.East);
     appWin.setTabPosition(Qt.TopDockWidgetArea, QTabWidget.South);
-    appWin.setTabPosition(Qt.BottomDockWidgetArea, QTabWidget.West);
+    appWin.setTabPosition(Qt.BottomDockWidgetArea, QTabWidget.South);
 
     setUpDragAndDrop(appWin);
 
-    appWin.windowIcon = new QIcon("scripts/qcad_icon.png");
+    appWin.windowIcon = new QIcon(autoPath("scripts/qcad_icon.png"));
     if (!ignoreDockappWindows) {
         appWin.readSettings();
     }
 
     RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindowBeforeShow);
 
-    if (!QCoreApplication.arguments().contains("-no-show")) {
+    if (!args.contains("-no-show")) {
         appWin.show();
     }
 
-    postInitAddOns(addOns, splash);
-    RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindow);
-
     if (!isNull(splash)) {
         splash.close();
-        splash.destroy();
+        destrDialog(splash);
     }
 
+    postInitAddOns(addOns);
+    RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindow);
+
     // if the window position / size was not read from a config file,
     // automatically position property editor and library browser (first start):
     if (isFirstStart) {
@@ -729,7 +672,7 @@ function main() {
         }
     }
 
-    // open files clicked in Finder if application is alreay running (Mac):
+    // open files clicked in Finder if application is already running (Mac):
     qApp.fileOpenRequestReceived.connect(function(fileName) {
         openFiles([fileName], false);
     });
@@ -740,7 +683,13 @@ function main() {
     // open files given on command line:
     var clickedFilesAndArgs = filesToOpen.concat(args.slice(1));
     QCoreApplication.processEvents();
-    openFiles(clickedFilesAndArgs, !recovered);
+    appWin.setProperty("starting", true);
+    var restored = false;
+    if (typeof(restoreFiles)=="function") {
+        restored = restoreFiles();
+    }
+    openFiles(clickedFilesAndArgs, !recovered && !restored);
+    appWin.setProperty("starting", false);
 
     RPluginLoader.postInitPlugins(RPluginInterface.LoadedFiles);
 
@@ -762,7 +711,24 @@ function main() {
         w.setFocus();
     }
 
-    if (!RSettings.hasQuitFlag()) {
+    if (RSettings.getQtVersion()<0x060000) {
+        if (!RSettings.hasQuitFlag()) {
+            // start and enter the main application loop:
+            QCoreApplication.exec();
+        }
+    }
+    else {
+        // Qt 6: always enter main application loop but quit immediately from the loop
+        // if -quit flag is given
+        if (RSettings.hasQuitFlag()) {
+            var singleShot = new QTimer(qApp);
+            singleShot.singleShot = true;
+            singleShot.timeout.connect(function() {
+                QCoreApplication.quit();
+            });
+            singleShot.start(100);
+        }
+
         // start and enter the main application loop:
         QCoreApplication.exec();
     }
@@ -772,7 +738,7 @@ function main() {
     // don't use RSettings below this point
 
     // and we're done:
-    appWin.destroy();
+    destr(appWin);
     qDebug("done");
 }
 
